Index: apps/app_mp3.c
===================================================================
RCS file: /usr/cvsroot/asterisk/apps/app_mp3.c,v
retrieving revision 1.5
diff -u -r1.5 app_mp3.c
--- apps/app_mp3.c	8 Sep 2003 16:48:06 -0000	1.5
+++ apps/app_mp3.c	14 Sep 2003 17:20:38 -0000
@@ -28,6 +28,7 @@
 #include <pthread.h>
 #include <sys/time.h>
 
+#define LOCAL_MPG_123 "/usr/local/bin/mpg123"
 #define MPG_123 "/usr/bin/mpg123"
 
 static char *tdesc = "Silly MP3 Application";
@@ -60,10 +61,22 @@
 			close(x);
 	}
 	/* Execute mpg123, but buffer if it's a net connection */
-	if (strncmp(filename, "http://", 7)) 
-	    execl(MPG_123, MPG_123, "-q", "-s", "-b", "1024", "--mono", "-r", "8000", filename, (char *)NULL);
-	else
-	    execl(MPG_123, MPG_123, "-q", "-s", "--mono", "-r", "8000", filename, (char *)NULL);
+	if (strncmp(filename, "http://", 7)) {
+		/* Most commonly installed in /usr/local/bin */
+	    execl(LOCAL_MPG_123, "mpg123", "-q", "-s", "-b", "1024", "--mono", "-r", "8000", filename, (char *)NULL);
+		/* But many places has it in /usr/bin */
+	    execl(MPG_123, "mpg123", "-q", "-s", "-b", "1024", "--mono", "-r", "8000", filename, (char *)NULL);
+		/* As a last-ditch effort, try to use PATH */
+	    execlp("mpg123", "mpg123", "-q", "-s", "-b", "1024", "--mono", "-r", "8000", filename, (char *)NULL);
+	}
+	else {
+		/* Most commonly installed in /usr/local/bin */
+	    execl(MPG_123, "mpg123", "-q", "-s", "--mono", "-r", "8000", filename, (char *)NULL);
+		/* But many places has it in /usr/bin */
+	    execl(LOCAL_MPG_123, "mpg123", "-q", "-s", "--mono", "-r", "8000", filename, (char *)NULL);
+		/* As a last-ditch effort, try to use PATH */
+	    execlp("mpg123", "mpg123", "-q", "-s", "--mono", "-r", "8000", filename, (char *)NULL);
+	}
 	ast_log(LOG_WARNING, "Execute of mpg123 failed\n");
 	return -1;
 }
Index: res/res_musiconhold.c
===================================================================
RCS file: /usr/cvsroot/asterisk/res/res_musiconhold.c,v
retrieving revision 1.8
diff -u -r1.8 res_musiconhold.c
--- res/res_musiconhold.c	8 Sep 2003 16:48:07 -0000	1.8
+++ res/res_musiconhold.c	14 Sep 2003 17:20:39 -0000
@@ -94,6 +94,7 @@
 
 static ast_mutex_t moh_lock = AST_MUTEX_INITIALIZER;
 
+#define LOCAL_MPG_123 "/usr/local/bin/mpg123"
 #define MPG_123 "/usr/bin/mpg123"
 #define MAX_MP3S 256
 
@@ -121,7 +122,7 @@
 		ast_log(LOG_WARNING, "%s is not a valid directory\n", class->dir);
 		return -1;
  	}
-	argv[0] = MPG_123;
+	argv[0] = "mpg123";
 	argv[1] = "-q";
 	argv[2] = "-s";
 	argv[3] = "--mono";
@@ -190,7 +191,12 @@
 			close(x);
 		/* Child */
 		chdir(class->dir);
+		/* Default install is /usr/local/bin */
+		execv(LOCAL_MPG_123, argv);
+		/* Many places have it in /usr/bin */
 		execv(MPG_123, argv);
+		/* Check PATH as a last-ditch effort */
+		execvp("mpg123", argv);
 		ast_log(LOG_WARNING, "Exec failed: %s\n", strerror(errno));
 		exit(1);
 	} else {
